package com.crm.manager.service;

import com.crm.manager.configuration.FeignMultipartSupportConfig;
import com.crm.rely.backend.core.dto.base.BaseResultDto;
import com.crm.rely.backend.core.dto.base.ResultWithPagerDto;
import com.crm.rely.backend.model.dto.custom.login.CustomLoginAssetManagementDto;
import com.crm.rely.backend.model.dto.custom.login.CustomLoginDemoDto;
import com.crm.rely.backend.model.dto.custom.login.CustomLoginDto;
import com.crm.rely.backend.model.dto.custom.login.CustomLoginFirmOfferDto;
import com.crm.rely.backend.model.entity.custom.login.CustomLoginApproveEntity;
import com.crm.rely.backend.model.entity.custom.login.CustomLoginSearchListEntity;
import com.crm.rely.backend.model.entity.custom.login.asset.management.CustomLoginAssetManagementApproveEntity;
import com.crm.rely.backend.model.entity.custom.login.asset.management.CustomLoginAssetManagementSearchListEntity;
import com.crm.rely.backend.model.entity.custom.login.demo.CustomLoginDemoApproveEntity;
import com.crm.rely.backend.model.entity.custom.login.demo.CustomLoginDemoSearchListEntity;
import com.crm.rely.backend.model.entity.custom.login.firm.offer.CustomLoginFirmOfferApproveEntity;
import com.crm.rely.backend.model.entity.custom.login.firm.offer.CustomLoginFirmOfferSearchListEntity;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;

@FeignClient(name = "GOLDEN-CUSTOM-SERVICE", configuration = FeignMultipartSupportConfig.class, path = "/custom/login/manager")
public interface CustomLoginFeignService {

    @PostMapping("/demo/approve")
    BaseResultDto approveDemo(CustomLoginDemoApproveEntity entity) throws Exception;

    @PostMapping("/demo/search/list")
    ResultWithPagerDto<CustomLoginDemoDto> searchDemoPageList(CustomLoginDemoSearchListEntity entity) throws Exception;

    @PostMapping("/firm/offer/approve")
    BaseResultDto approveFirmOffer(CustomLoginFirmOfferApproveEntity entity) throws Exception;

    @PostMapping("/firm/offer/search/list")
    ResultWithPagerDto<CustomLoginFirmOfferDto> searchFirmOfferPageList(CustomLoginFirmOfferSearchListEntity entity) throws Exception;
    @PostMapping("/asset/management/approve")
    BaseResultDto approveAssetManagement(CustomLoginAssetManagementApproveEntity entity) throws Exception;

    @PostMapping("/asset/management/search/list")
    ResultWithPagerDto<CustomLoginAssetManagementDto> searchAssetManagementPageList(CustomLoginAssetManagementSearchListEntity entity) throws Exception;

    @PostMapping("/approve")
    BaseResultDto approve(CustomLoginApproveEntity entity) throws Exception;

    @PostMapping("/search/list")
    ResultWithPagerDto<CustomLoginDto> searchPageList(CustomLoginSearchListEntity entity) throws Exception;
}
